##  Scaling Your Modernization
After you complete your first application modernization use case with SAP LeanIX, you will have a proof of concept that shows benefits for the entire organization. This success can help expand the scope to other domains. You can then define the to-be state and start transformation efforts in other departments. As your capabilities grow, you will be ready to handle complex initiatives like an [ERP Transformation](https://help.sap.com/docs/leanix/ea/erp-transformation?locale=en-US&state=PRODUCTION&version=CLOUD "Step-by-step guide for ERP Transformation using SAP LeanIX.").
